summaryrefslogtreecommitdiffstats
path: root/mod_perl.pl
diff options
context:
space:
mode:
Diffstat (limited to 'mod_perl.pl')
-rw-r--r--mod_perl.pl7
1 files changed, 4 insertions, 3 deletions
diff --git a/mod_perl.pl b/mod_perl.pl
index 1f4593f00..572bcc7f9 100644
--- a/mod_perl.pl
+++ b/mod_perl.pl
@@ -135,9 +135,10 @@ sub handler : method {
Bugzilla::init_page();
my $result = $class->SUPER::handler(@_);
- # When returning data from the REST api, tell Apache not to append its
- # error html documents to the response.
- return Bugzilla->usage_mode == USAGE_MODE_REST
+ # When returning data from the REST api we must only return 200 or 304,
+ # which tells Apache not to append its error html documents to the
+ # response.
+ return Bugzilla->usage_mode == USAGE_MODE_REST && $result != 304
? Apache2::Const::OK
: $result;
}